package com.common.entity.RuleContent;


public class Cropper_paramsType {
    private String head_key;
    private Integer head_offset;
    private String tail_key;
    private Integer tail_offset;

    // Constructors
    public Cropper_paramsType() {}

    // Getters and Setters
    public String gethead_key() {
        return head_key;
    }

    public void sethead_key(String head_key) {
        this.head_key = head_key;
    }

    public Integer gethead_offset() {
        return head_offset;
    }

    public void sethead_offset(Integer head_offset) {
        this.head_offset = head_offset;
    }

    public String gettail_key() {
        return tail_key;
    }

    public void settail_key(String tail_key) {
        this.tail_key = tail_key;
    }

    public Integer gettail_offset() {
        return tail_offset;
    }

    public void settail_offset(Integer tail_offset) {
        this.tail_offset = tail_offset;
    }

}
